.. _package-connection:

:mod:`connection` Package
=========================

.. automodule:: odoo_rpc_client.connection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`connection` Module
------------------------

.. automodule:: odoo_rpc_client.connection.connection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`jsonrpc` Module
---------------------

.. automodule:: odoo_rpc_client.connection.jsonrpc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`xmlrpc` Module
--------------------

.. automodule:: odoo_rpc_client.connection.xmlrpc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`local` Module
--------------------

.. automodule:: odoo_rpc_client.connection.local
    :members:
    :undoc-members:
    :show-inheritance:

